@@ -1,5 +1,6 @@
 # coding=utf-8
 from .._impl import (
+    api_rids_AiConversationRid as AiConversationRid,
     api_rids_AttachmentRid as AttachmentRid,
     api_rids_AutomaticCheckEvaluationRid as AutomaticCheckEvaluationRid,
     api_rids_ChunkRid as ChunkRid,
@@ -21,6 +22,7 @@ from .._impl import (
 )
 
 __all__ = [
+    'AiConversationRid',
     'AttachmentRid',
     'AutomaticCheckEvaluationRid',
     'ChunkRid',
