@@ -1,14 +1,23 @@
 # coding=utf-8
 from .._impl import (
+    event_AggregateEventsRequest as AggregateEventsRequest,
+    event_AggregateEventsResponse as AggregateEventsResponse,
+    event_AggregateType as AggregateType,
+    event_AggregateValue as AggregateValue,
+    event_AggregateValueVisitor as AggregateValueVisitor,
     event_ApiEventOrigin as ApiEventOrigin,
     event_ArchiveEvent as ArchiveEvent,
+    event_AssetsFilter as AssetsFilter,
+    event_AssigneesFilter as AssigneesFilter,
     event_BatchUpdateDispositionRequest as BatchUpdateDispositionRequest,
     event_BatchUpdateDispositionResponse as BatchUpdateDispositionResponse,
     event_BatchUpdateEventRequest as BatchUpdateEventRequest,
     event_BatchUpdateEventResponse as BatchUpdateEventResponse,
     event_CheckOriginMetadata as CheckOriginMetadata,
     event_CreateEvent as CreateEvent,
+    event_DataReviewChecksFilter as DataReviewChecksFilter,
     event_DataReviewEventOrigin as DataReviewEventOrigin,
+    event_DataReviewsFilter as DataReviewsFilter,
     event_Event as Event,
     event_EventDisposition as EventDisposition,
     event_EventDispositionStatus as EventDispositionStatus,
@@ -25,6 +34,7 @@ from .._impl import (
     event_HistogramFilterQuery as HistogramFilterQuery,
     event_HistogramFilterQueryVisitor as HistogramFilterQueryVisitor,
     event_ListPropertiesAndLabelsRequest as ListPropertiesAndLabelsRequest,
+    event_OriginTypesFilter as OriginTypesFilter,
     event_ProcedureEventOrigin as ProcedureEventOrigin,
     event_SearchEventOriginType as SearchEventOriginType,
     event_SearchEventsRequest as SearchEventsRequest,
@@ -44,15 +54,24 @@ from .._impl import (
 )
 
 __all__ = [
+    'AggregateEventsRequest',
+    'AggregateEventsResponse',
+    'AggregateType',
+    'AggregateValue',
+    'AggregateValueVisitor',
     'ApiEventOrigin',
     'ArchiveEvent',
+    'AssetsFilter',
+    'AssigneesFilter',
     'BatchUpdateDispositionRequest',
     'BatchUpdateDispositionResponse',
     'BatchUpdateEventRequest',
     'BatchUpdateEventResponse',
     'CheckOriginMetadata',
     'CreateEvent',
+    'DataReviewChecksFilter',
     'DataReviewEventOrigin',
+    'DataReviewsFilter',
     'Event',
     'EventDisposition',
     'EventDispositionStatus',
@@ -68,6 +87,7 @@ __all__ = [
     'HistogramFilterQuery',
     'HistogramFilterQueryVisitor',
     'ListPropertiesAndLabelsRequest',
+    'OriginTypesFilter',
     'ProcedureEventOrigin',
     'SearchEventOriginType',
     'SearchEventsRequest',
