@@ -29,6 +29,7 @@ from .._impl import (
     ingest_api_ExistingDatasetIngestDestination as ExistingDatasetIngestDestination,
     ingest_api_ExistingVideoIngestDestination as ExistingVideoIngestDestination,
     ingest_api_FileExtractionInput as FileExtractionInput,
+    ingest_api_FileExtractionParameter as FileExtractionParameter,
     ingest_api_FileFilter as FileFilter,
     ingest_api_FileFilterVisitor as FileFilterVisitor,
     ingest_api_FileOutputFormat as FileOutputFormat,
@@ -95,6 +96,7 @@ from .._impl import (
     ingest_api_ParquetOpts as ParquetOpts,
     ingest_api_Part as Part,
     ingest_api_PartWithSize as PartWithSize,
+    ingest_api_PresignedFileIngestSource as PresignedFileIngestSource,
     ingest_api_PublicAuthentication as PublicAuthentication,
     ingest_api_RegisterContainerizedExtractorRequest as RegisterContainerizedExtractorRequest,
     ingest_api_RegisterContainerizedExtractorResponse as RegisterContainerizedExtractorResponse,
@@ -157,6 +159,7 @@ __all__ = [
     'ExistingDatasetIngestDestination',
     'ExistingVideoIngestDestination',
     'FileExtractionInput',
+    'FileExtractionParameter',
     'FileFilter',
     'FileFilterVisitor',
     'FileOutputFormat',
@@ -222,6 +225,7 @@ __all__ = [
     'ParquetOpts',
     'Part',
     'PartWithSize',
+    'PresignedFileIngestSource',
     'PublicAuthentication',
     'RegisterContainerizedExtractorRequest',
     'RegisterContainerizedExtractorResponse',
