@@ -288,6 +288,9 @@ from .._impl import (
     scout_compute_api_RangesNumericAggregation as RangesNumericAggregation,
     scout_compute_api_RangesSummary as RangesSummary,
     scout_compute_api_Reference as Reference,
+    scout_compute_api_RefpropProperty as RefpropProperty,
+    scout_compute_api_RefpropSeries as RefpropSeries,
+    scout_compute_api_RefpropSubstance as RefpropSubstance,
     scout_compute_api_RollingOperationSeries as RollingOperationSeries,
     scout_compute_api_RollingOperator as RollingOperator,
     scout_compute_api_RollingOperatorVisitor as RollingOperatorVisitor,
@@ -666,6 +669,9 @@ __all__ = [
     'RangesNumericAggregation',
     'RangesSummary',
     'Reference',
+    'RefpropProperty',
+    'RefpropSeries',
+    'RefpropSubstance',
     'RollingOperationSeries',
     'RollingOperator',
     'RollingOperatorVisitor',
