@@ -112,6 +112,7 @@ from .._impl import (
     scout_compute_resolved_api_RawLogSeriesNode as RawLogSeriesNode,
     scout_compute_resolved_api_RawNumericSeriesNode as RawNumericSeriesNode,
     scout_compute_resolved_api_RawUntypedSeriesNode as RawUntypedSeriesNode,
+    scout_compute_resolved_api_RefpropSeriesNode as RefpropSeriesNode,
     scout_compute_resolved_api_ResampleConfiguration as ResampleConfiguration,
     scout_compute_resolved_api_ResampleInterpolationConfiguration as ResampleInterpolationConfiguration,
     scout_compute_resolved_api_ResampleInterpolationConfigurationVisitor as ResampleInterpolationConfigurationVisitor,
@@ -278,6 +279,7 @@ __all__ = [
     'RawLogSeriesNode',
     'RawNumericSeriesNode',
     'RawUntypedSeriesNode',
+    'RefpropSeriesNode',
     'ResampleConfiguration',
     'ResampleInterpolationConfiguration',
     'ResampleInterpolationConfigurationVisitor',
