@@ -12,6 +12,7 @@ from .._impl import (
     scout_video_api_ErrorIngestStatus as ErrorIngestStatus,
     scout_video_api_ErrorType as ErrorType,
     scout_video_api_FileSummary as FileSummary,
+    scout_video_api_GenerateWhepStreamResponse as GenerateWhepStreamResponse,
     scout_video_api_GenerateWhipStreamResponse as GenerateWhipStreamResponse,
     scout_video_api_GetEnrichedVideoIngestStatusRequest as GetEnrichedVideoIngestStatusRequest,
     scout_video_api_GetFileSummariesRequest as GetFileSummariesRequest,
@@ -76,6 +77,7 @@ __all__ = [
     'ErrorIngestStatus',
     'ErrorType',
     'FileSummary',
+    'GenerateWhepStreamResponse',
     'GenerateWhipStreamResponse',
     'GetEnrichedVideoIngestStatusRequest',
     'GetFileSummariesRequest',
